/*

  Copyright (C) 2020 willipink.eu
  Author Moritz Münch moritzmuench@mailbox.org

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>. */



/* create a modal dialog */
class Modal {

    constructor(modal, callback, callback_arguments) {

        this.modal = modal;
        this.callback = callback;
        this.callback_arguments = callback_arguments;

        $('#' + this.modal + '_show')
            .bind('click', {this: this}, function(event) {
                event.data.this.show();
        });
    }


    /* show the modal dialog */
    show() {

        $('#' + this.modal).fadeIn('fast');

        /* close modal on click outside of modal */
        $(document)
            .bind('click', {this: this}, function(event) {
                let scope = event.data.this
                if ($('#' + scope.modal).is(':visible')) {
                    if ($(event.target).attr('id') === scope.modal) {
                        hide(scope.modal);
                    }
                }
            });

        /* close modal on keypress ESC, send modal on keypress ENTER */
        $(document)
            .bind('keypress', {this: this}, function(event) {
                if (event.keyCode == 27) {
                    hide(event.data.this.modal);
                    $(document).off('keypress');
                } else if (event.keyCode == 13) {
                    event.data.this.submit();
                }
            });

        /* close modal on button #<modal_name>_close */
        $('#' + this.modal + '_close')
            .bind('click', {this: this}, function(event) {
                hide(event.data.this.modal);
            });

        /* trigger callback on button #<modal_name>_action */
        $('#' + this.modal + '_action')
            .bind('click', {this: this}, function(event) {
                event.data.this.submit();
            });

        /* focus first input text element */
        $('#' + this.modal + ' input:text:visible:first').focus();
    }


    /*submit modal */
    submit() {
        let response = {};
        $('#' + this.modal + ' input[type=text]').each(function() {
            response[$(this).attr('name')] = $(this).val();
        });
        this.callback(this.callback_arguments, response);
    }

}

/* hide the modal dialog */
function hide(modal) {
    $('#' + modal).fadeOut('fast');
}

/* detach all eventTypes */
function detach(modal) {
    hide(modal);
    $('#' + modal + '_action').off('click');
    $('#' + modal + '_close').off('click');
    $(document).off('keypress click');
    $('#' + modal + ' input:text:visible').each(function() {
        $(this).val(''); });
}

export { Modal, detach, hide };
